# dial-gui
GUI for the __dial-core__ framework.

| Build | Coverage | Quality | Version | Python | Docs | License |
|-------|----------|---------|---------|--------|------|---------|
| [![Build Status](https://travis-ci.com/dial-app/dial-gui.svg?branch=master)](https://travis-ci.com/dial-app/dial-gui) 	| [![codecov](https://codecov.io/gh/dial-app/dial-gui/branch/master/graph/badge.svg)](https://codecov.io/gh/dial-app/dial-gui) 	| [![Codacy Badge](https://api.codacy.com/project/badge/Grade/eb5224f0cc3f481aa5d419b4bfc86f41)](https://www.codacy.com/gh/dial-app/dial-gui?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=dial-app/dial-gui&amp;utm_campaign=Badge_Grade) 	| [![PyPI](https://img.shields.io/pypi/v/dial-gui)](https://pypi.org/project/dial-gui/) 	| [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/dial-gui?color=green)](https://pypi.org/project/dial-gui/) 	| [![ReadTheDocs](https://readthedocs.org/projects/dial-gui/badge/?version=latest)](https://dial-gui.readthedocs.io/) 	| [![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0) |

## Documentation

This project's documentation lives at [readthedocs.io](https://dial-gui.readthedocs.io).

## License

All code is provided under the __GPL-3.0__ license. See [LICENSE](LICENSE) for more details.

## Authors

* **David Afonso (davafons)**: [Github](https://github.com/davafons) [Twitter](https://twitter.com/davafons)
